@@ -876,7 +876,6 @@ proc_wkd_get (ctrl_t ctrl, assuan_context_t ctx, char *line)
       if (domaininfo_is_wkd_not_supported (domain_orig))
         {
           err = gpg_error (GPG_ERR_NO_DATA);
-          dirmngr_status_printf (ctrl, "NOTE", "wkd_cached_result %u", err);
           goto leave;
         }
     }
@@ -2526,7 +2525,7 @@ static const char hlp_ks_put[] =
   "  INQUIRE KEYBLOCK_INFO\n"
   "\n"
   "The client shall respond with a colon delimited info lines (the output\n"
-  "of 'gpg --list-keys --with-colons KEYID').\n";
+  "of 'for x in keys sigs; do gpg --list-$x --with-colons KEYID; done').\n";
 static gpg_error_t
 cmd_ks_put (assuan_context_t ctx, char *line)
 {
@@ -2559,7 +2558,8 @@ cmd_ks_put (assuan_context_t ctx, char *line)
       goto leave;
     }
 
-  /* Ask for the key meta data.  */
+  /* Ask for the key meta data. Not actually needed for HKP servers
+     but we do it anyway to test the client implementation.  */
   err = assuan_inquire (ctx, "KEYBLOCK_INFO",
                         &info, &infolen, MAX_KEYBLOCK_LENGTH);
   if (err)
@@ -2717,7 +2717,7 @@ cmd_killdirmngr (assuan_context_t ctx, char *line)
 
   ctrl->server_local->stopme = 1;
   assuan_set_flag (ctx, ASSUAN_FORCE_CLOSE, 1);
-  return 0;
+  return gpg_error (GPG_ERR_EOF);
 }
 
 
